@@ -5,12 +5,12 @@ import logging
 import threading
 import uuid
 from asyncio import Lock
-from typing import Optional, Type
+from typing import Optional
 from urllib.parse import urlparse
 
 import paho.mqtt.client as mqtt
 
-from .api import COMMANDS_SECURED, KEEPALIVE, RT, RoborockClient, md5hex
+from .api import COMMANDS_SECURED, KEEPALIVE, RoborockClient, md5hex
 from .containers import DeviceData, UserData
 from .exceptions import CommandVacuumError, RoborockException, VacuumError
 from .protocol import MessageParser, Utils
@@ -149,12 +149,11 @@ class RoborockMqttClient(RoborockClient, mqtt.Client):
         if info.rc != mqtt.MQTT_ERR_SUCCESS:
             raise RoborockException(f"Failed to publish ({mqtt.error_string(info.rc)})")
 
-    async def send_command(
+    async def _send_command(
         self,
         method: RoborockCommand,
         params: Optional[list | dict] = None,
-        return_type: Optional[Type[RT]] = None,
-    ) -> RT:
+    ):
         await self.validate_connection()
         request_id, timestamp, payload = super()._get_payload(method, params, True)
         _LOGGER.debug(f"id={request_id} Requesting method {method} with {params}")
@@ -165,15 +164,17 @@ class RoborockMqttClient(RoborockClient, mqtt.Client):
         msg = MessageParser.build(roborock_message, local_key, False)
         self._send_msg_raw(msg)
         (response, err) = await self._async_response(request_id, response_protocol)
-        self._diagnostic_data[method.name] = {"params": params, "response": response, "error": err}
+        self._diagnostic_data[method if method is not None else "unknown"] = {
+            "params": params,
+            "response": response,
+            "error": err,
+        }
         if err:
             raise CommandVacuumError(method, err) from err
         if response_protocol == 301:
             _LOGGER.debug(f"id={request_id} Response from {method}: {len(response)} bytes")
         else:
             _LOGGER.debug(f"id={request_id} Response from {method}: {response}")
-        if return_type:
-            return return_type.from_dict(response)
         return response
 
     async def get_map_v1(self):
